"""
"""

import argparse
import getpass
import json
import logging
import os

from . import auth
from . import record


logger = logging.getLogger(__name__)


def main():
    parser = argparse.ArgumentParser(description='Get your Concordia University Student Record.')
    logging_group = parser.add_argument_group('logging level').add_mutually_exclusive_group()
    logging_group.add_argument('-v', '--verbose', action='store_const',
                               const=logging.INFO, default=logging.CRITICAL,
                               dest='loglevel', help='enable verbose output')
    logging_group.add_argument('-d', '--debug', action='store_const',
                               const=logging.DEBUG, dest='loglevel',
                               help='show debugging statements')
    args = parser.parse_args()
    logging.basicConfig(level=args.loglevel)

    username = os.environ.get('CONU_USER') or input('CONU_USER: ')
    password = os.environ.get('CONU_PASS') or getpass.getpass('CONU_PASS: ')

    token = auth.get_token(username, password)
    student_record = record.get_student_record(token)

    print(json.dumps(student_record, indent=2, sort_keys=True))
