"""
"""

import logging

import requests


logger = logging.getLogger(__name__)
sisservice_url = 'https://genesis.concordia.ca/mportal2.0/services/sisservice.ashx'


def _sort_record(record):
    # sort programs
    record['programs'] = sorted(record['programs'], key=lambda k: k['program']['code'])

    # sort terms
    for program_index, program in enumerate(record['programs']):
        record['programs'][program_index]['terms'] = sorted(program['terms'], key=lambda k: k['term']['code'])

    # sort courses
    for program_index, program in enumerate(record['programs']):
        for term_index, term in enumerate(program['terms']):
            record['programs'][program_index]['terms'][term_index]['courses'] = \
                sorted(term['courses'], key=lambda x: (x['course']['subject'], x['course']['catalog'], x['course']['section'], x['professor']))

    return record


def get_student_record(token):
    logger.info('Getting student record')
    data = {
        'token': token,
        'method': 'get-my-student-record',
    }
    r = requests.post(sisservice_url, data=data)
    student_record = r.json()['result']
    student_record = _sort_record(student_record)
    logger.info('Returning student record')
    return student_record
